==> dtkwidget_2.0.7.2.orig.tar.gz: dtkwidget-2.0.7.2/translations/dtkwidget2_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../src/widgets/daboutdialog.cpp" line="191"/>
        <source>Acknowledgements</source>
        <translation>鸣谢</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="712"/>
        <source>Version: %1</source>
        <translation>版本：%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="716"/>
        <source>%1 is released under %2</source>
        <translation>%1遵循%2协议发布</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="530"/>
        <source>Black</source>
        <translation>黑色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="533"/>
        <source>White</source>
        <translation>白色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="536"/>
        <source>Dark Gray</source>
        <translation>深灰色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="539"/>
        <source>Gray</source>
        <translation>灰色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="542"/>
        <source>Light Gray</source>
        <translation>浅灰色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="545"/>
        <source>Red</source>
        <translation>红色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="548"/>
        <source>Green</source>
        <translation>绿色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="551"/>
        <source>Blue</source>
        <translation>蓝色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="554"/>
        <source>Cyan</source>
        <translation>青色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="557"/>
        <source>Magenta</source>
        <translation>洋红色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="560"/>
        <source>Yellow</source>
        <translation>黄色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="563"/>
        <source>Dark Red</source>
        <translation>深红色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="566"/>
        <source>Dark Green</source>
        <translation>深绿色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="569"/>
        <source>Dark Blue</source>
        <translation>深蓝色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="572"/>
        <source>Dark Cyan</source>
        <translation>深青色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="575"/>
        <source>Dark Magenta</source>
        <translation>深紫红色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="578"/>
        <source>Dark Yellow</source>
        <translation>深黄色</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>请输入新的快捷键</translation>
    </message>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>无</translation>
    </message>
</context>
<context>
    <name>DSimpleListView</name>
    <message>
        <source>No search result</source>
        <translation type="vanished">无搜索结果</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/widgets/private/settings/content.cpp" line="189"/>
        <source>Restore Defaults</source>
        <translation>恢复默认设置</translation>
    </message>
    <message>
        <location filename="../src/widgets/dsimplelistview.cpp" line="1190"/>
        <source>No search result</source>
        <translation>无搜索结果</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/widgets/private/settings/shortcutedit.cpp" line="119"/>
        <source>Please enter a new shortcut</source>
        <translation>请输入新的快捷键</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="449"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="456"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="463"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
</TS>

==> dtkwidget_2.0.9.3.orig.tar.gz: dtkwidget-2.0.9.3/translations/dtkwidget2_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../src/widgets/daboutdialog.cpp" line="191"/>
        <source>Acknowledgements</source>
        <translation>鸣谢</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="712"/>
        <source>Version: %1</source>
        <translation>版本：%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/dapplication.cpp" line="716"/>
        <source>%1 is released under %2</source>
        <translation>%1遵循%2协议发布</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="530"/>
        <source>Black</source>
        <translation>黑色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="533"/>
        <source>White</source>
        <translation>白色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="536"/>
        <source>Dark Gray</source>
        <translation>深灰色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="539"/>
        <source>Gray</source>
        <translation>灰色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="542"/>
        <source>Light Gray</source>
        <translation>浅灰色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="545"/>
        <source>Red</source>
        <translation>红色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="548"/>
        <source>Green</source>
        <translation>绿色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="551"/>
        <source>Blue</source>
        <translation>蓝色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="554"/>
        <source>Cyan</source>
        <translation>青色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="557"/>
        <source>Magenta</source>
        <translation>洋红色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="560"/>
        <source>Yellow</source>
        <translation>黄色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="563"/>
        <source>Dark Red</source>
        <translation>深红色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="566"/>
        <source>Dark Green</source>
        <translation>深绿色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="569"/>
        <source>Dark Blue</source>
        <translation>深蓝色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="572"/>
        <source>Dark Cyan</source>
        <translation>深青色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="575"/>
        <source>Dark Magenta</source>
        <translation>深紫红色</translation>
    </message>
    <message>
        <location filename="../src/widgets/dcrumbedit.cpp" line="578"/>
        <source>Dark Yellow</source>
        <translation>深黄色</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>请输入新的快捷键</translation>
    </message>
    <message>
        <location filename="../src/widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>无</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/widgets/private/settings/content.cpp" line="189"/>
        <source>Restore Defaults</source>
        <translation>恢复默认设置</translation>
    </message>
    <message>
        <location filename="../src/widgets/dsimplelistview.cpp" line="1235"/>
        <source>No search result</source>
        <translation>无搜索结果</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/widgets/private/settings/shortcutedit.cpp" line="119"/>
        <source>Please enter a new shortcut</source>
        <translation>请输入新的快捷键</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="449"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="456"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../src/widgets/dtitlebar.cpp" line="463"/>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
</TS>
